@@ -1,11 +1,10 @@
-#![feature(async_closure)]
 mod client;
 mod test_controller;
 mod test_struct;
 
 use crate::test_controller::ImplCreateController;
 use log::LevelFilter;
-use netxserver::{NetXServer, ServerOption};
+use netxserver::prelude::*;
 use std::error::Error;
 
 #[global_allocator]
